#! /bin/sh

# @param String message - The message to log
readonly LOG_MESSAGE_COMMAND=$(basename "${0}")
logMessage()
{
  echo "$(date '+%a %b %e %T %Y') $LOG_MESSAGE_COMMAND: "${@} >> "${SCRIPT_LOG_FILE}"
}

disableProxy()
{
    logMessage "Proxy enabled"
    PORT=`networksetup -getwebproxy "$NETSET" |
    cut -d':' -f2 |
    head -3 |
    tail -n 1`

    if [ $PORT == $FINDPORT ]; then
      logMessage "Found port: ${PORT}"
      logMessage "Disabling Proxy"
      networksetup -setwebproxystate "$NETSET" off
    fi
}

restoreProxyBypassDomains()
{
  logMessage "Restoring previously saved proxy bypass domains..."
  DOMAINS=`defaults read com.tunnelbear.mac.TunnelBear savedProxyBypassDomains`

  if [ -z "$DOMAINS" ]; then
    logMessage "Nothing to restore"
  else
    logMessage "Saved proxy bypass domains: $DOMAINS"
    networksetup -setproxybypassdomains "$NETSET" $DOMAINS
    defaults delete com.tunnelbear.mac.TunnelBear savedProxyBypassDomains
  fi
}

################# START HERE ####################

readonly SCRIPT_LOG_FILE="/var/log/tbeard/vigilant.log"

FINDPORT=$1

NETSET=`defaults read com.tunnelbear.mac.TunnelBear savedProxyInterface`
defaults delete com.tunnelbear.mac.TunnelBear savedProxyInterface

if [ -z "$NETSET" ]; then
   logMessage "No saved proxy interface, using default"

    DEFAULT_INTERFACE=`netstat -nr |
                    grep -m1 default |
                    awk '{ if ($1 == "default") print $NF }'`

    NETSET=`networksetup -listnetworkserviceorder |
        grep -m1 $DEFAULT_INTERFACE |
        awk '{ split($0, a, ":"); split(a[2], b, ","); print b[1] }' |
        sed -e 's/^[ \t]*//'`
else
    logMessage "Found saved proxy interface: $NETSET"
fi

ISENABLED=`networksetup -getwebproxy "$NETSET" |
           grep "^Enabled:" |
           awk -F': ' '{print $NF}'`


logMessage "FINDPORT: $FINDPORT"
logMessage "NETSET: $NETSET"
logMessage "isEnabled: $ISENABLED"

if [ "$ISENABLED" == "Yes" ]; then
  restoreProxyBypassDomains
  disableProxy
else
  logMessage "Already disabled, standing down"
fi
