#!/bin/bash

# @param String message - The message to log
readonly LOG_MESSAGE_COMMAND=$(basename "${0}")
logMessage()
{
	echo "$(date '+%a %b %e %T %Y') $LOG_MESSAGE_COMMAND: "${@} >> "${SCRIPT_LOG_FILE}"
}

saveIPv6()
{
	logMessage "Saving current IPv6 configuration..."
	INFO=`networksetup -getinfo "$DEFAULT_SERVICE"`
	IPV6_TYPE=`echo $INFO | grep -oEm1 "(Manual|Automatic|Off)"`

	if [ "$IPV6_TYPE" == '' ] ; then
		IPV6_TYPE="LinkLocal";
	fi

	logMessage "IPv6 Configuration Type: $IPV6_TYPE"

	if [ "$IPV6_TYPE" == 'Off' ] ; then
		return;
	fi

	defaults write com.tunnelbear.Mac.TunnelBear savedIPv6.type $IPV6_TYPE;

	if [ "$IPV6_TYPE" == 'Manual' ] ; then
		logMessage "Manual IPv6 configuration, need to save"
		IPV6_ADDRESS=`echo $INFO | grep -oE "IPv6 IP address: .*? " | cut -d" " -f4`
		IPV6_ROUTER=`echo $INFO | grep -oE "IPv6 Router: .*? " | cut -d" " -f3`
		IPV6_PREFLEN=`echo $INFO | grep -oE "IPv6 Prefix Length: .*? " | cut -d" " -f4`
		logMessage "Address: $IPV6_ADDRESS"
		logMessage "Router: $IPV6_ROUTER"
		logMessage "Prefix Length: $IPV6_PREFLEN"

		defaults write com.tunnelbear.mac.TunnelBear savedIPv6.address $IPV6_ADDRESS;
		defaults write com.tunnelbear.mac.TunnelBear savedIPv6.router $IPV6_ROUTER;
		defaults write com.tunnelbear.mac.TunnelBear savedIPv6.preflen $IPV6_PREFLEN;
	fi
}

disableIPv6()
{
	networksetup -setv6off "$DEFAULT_SERVICE"
}

################# START HERE ####################

readonly SCRIPT_LOG_FILE="/var/log/tbeard/vigilant.log"

DEFAULT_INTERFACE=`netstat -nr |
grep -m1 default |
awk '{ if ($1 == "default") print $NF }'`
DEFAULT_IP=`ifconfig en0 |
sed -En 's/.*inet (addr:)?(([0-9]*\.){3}[0-9]*).*/\2/p'`
DEFAULT_SERVICE=`networksetup -listnetworkserviceorder |
				grep -m1 $DEFAULT_INTERFACE |
				awk '{ split($0, a, ":"); split(a[2], b, ","); print b[1] }' |
				sed -e 's/^[ \t]*//'`

	
logMessage "Default Interface: $DEFAULT_INTERFACE"
logMessage "Default Service: $DEFAULT_SERVICE"

saveIPv6
disableIPv6
